@@ -16,9 +16,8 @@ sub filter {
     return unless $args->{entry}->link =~ m!\.2ch\.net/test/read\.cgi|rss\.s2ch\.net/test/\-/!;
 
     my $body = $args->{entry}->body;
-    if ($body =~ s!^([^:]*):(\d{4}/\d\d/\d\d)\(.*?\) (\d\d:\d\d:\d\d)(?:\.\d\d)? (ID:\S+)?  ?!!) {
+    if ($body && $body =~ s!^([^:]*):(\d{4}/\d\d/\d\d)\(.*?\) (\d\d:\d\d:\d\d)(?:\.\d\d)? (ID:\S+)?  ?!!) {
         my($from, $day, $time, $id) = ($1, $2, $3, $4);
-
         my $date = Plagger::Date->strptime('%Y/%m/%d %H:%M:%S', "$day $time");
         $date->set_time_zone('Asia/Tokyo');
 
@@ -27,7 +26,8 @@ sub filter {
         $args->{entry}->date($date);
         $args->{entry}->author( $from ? "$from $id" : $id );
         $args->{entry}->body($body);
-    } elsif ($args->{entry}->title =~ /^\d+\-$/) {
+    } elsif ($args->{entry}->title =~ /^\d+\-$/
+             || ($body && $body =~ m!http://www\.2ch\.net/ad\.html *powerd by Big-Server\.!)) {
         $context->log(info => "Strip 2ch bogus entry " . $args->{entry}->title);
         $args->{feed}->delete_entry($args->{entry});
     }
